`safe-cast` is written and maintained by many contributors.

safe-cast: Authors
````````````````````````````

We'd like to thank the following people who have contributed to the `safe-cast` repository.

- Jeff Tanner <jefft@tune.com>
- Stas Yasinov <stas@tune.com>